@@ -13,14 +13,14 @@ $(document).ready(function () {
 			$(image).remove();
 		}
 	});
+});
 
-	// start fullPage.js
+function fullPageStart() {
 	$('#fullpage').fullpage({
-		//easing: 'linear',
 		//anchors: ['1', '2', '3'],
-		//navigation: true,
+		navigation: true,
 		navigationPosition: 'right',
-		navigationTooltips: ['- 1 -', '- 2 -', '- 3 -'],
+		//navigationTooltips: ['- 1 -', '- 2 -', '- 3 -'],
 		resize: false
 	});
-});
+}
